!**************************************************************************************************
! Pre-simulation procedure; initialization valuables
!**************************************************************************************************
SUBROUTINE init_value &
(LAT, W_sat, tmp_air, tmp_soil, prec, &
co2atm, ap, vp, vpd, dnsa, vp_sat, slope_vps, &
sl_hgt, dlen, rad, par, par_grass, &
albedo_soil, albedo_veg, radnet_soil, radnet_veg, &
gdd0, gdd5, aet, moist_factor, fire_factor, fire_clo, &
pool_w1, pool_w2, pool_w3, pool_snow, canopy_cond, pool_w1_RunningRecord, &
pool_litter, pool_som_int, pool_som_slow, &
stat_water, stat_water_RunningRecord, &
eK, lue, co2cmp, psat, &
pft, age, height, bole, dbh_heartwood, dbh_sapwood, crown_diameter, crown_area, la, &
mass_leaf, mass_trunk, mass_root, mass_stock, mass_available, &
bole_x, bole_y, crown_x, crown_y, tree_exist, height_limit, radius_limit, &
type_grass, C3g_no, C4g_no, &
gmass_leaf, gmass_root, gmass_available, gmass_stock, &
lai_grass, lai_opt_grass, &
pft_exist, patch_vacant, &
phenology, &
pheno_clo, pheno_cls, pheno_gdd, pheno_ncd, &
stat_leaf, stat_leaf_RunningRecord, &
c_emission, c_uptake, gpp, npp, gpp_month, npp_month, gpp_annual, npp_annual, &
establish_regu, &
tmp_air_RunningRecord, prec_RunningRecord, &
tmp_soil_RunningRecord, tmp_soil_month_ave, &
tmp_coldest_RunningRecord, tmp_coldest_20yr_ave, &
tmp_hottest_RunningRecord, tmp_hottest_20yr_ave, &
par_RunningRecord, &
tmp_ave_C3growth_RunningRecord, tmp_recorder_C3growth, &
tmp_ave_C4growth_RunningRecord, tmp_recorder_C4growth, &
gdd_20yr_RunningRecord, gdd_20yr_ave, npp_RunningRecord, npp_10d_ave, &
lai_opt_grass_RunningRecord, &
biome, &
hydRecord_preci, hydRecord_runoff, hydRecord_ic, hydRecord_ev, hydRecord_tr, &
mort_regu1, mort_regu2, mort_regu3 )

USE data_structure
implicit none

!location information
real               ,intent(IN)::LAT       !latitude  (degree)
real               ,intent(IN)::W_sat     !saturate point   (m3/m3, 0.0 -> 1.0)
real,dimension(365),intent(IN)::tmp_air   !2m air temperature (Celcius)
real,dimension(365),intent(IN)::tmp_soil  !soil temperature (Celcius)
real,dimension(365),intent(IN)::prec      !precipitation (mm day-1)

!air related
real co2atm       !ambient (canopy) CO2 concentration (ppmv)
real ap           !air pressure (hPa)
real vp           !vapour pressure (hPa)
real vpd          !vapour pressure deficit (hPa)
real dnsa         !density of air (kg m-3)
real vp_sat       !saturation vapour pressure (hPa)
real slope_vps    !slope of saturation vapour pressure related to tempertaure (hPa deg C-1)

!radiation related
real sl_hgt       !solar hight at midday (degree)
real dlen         !day length (hour)
real rad          !global radiation at the ground surface (W/m2)
real par          !photosynthetically active radiation of mid-day (micro mol photon m-2 s-1)
real par_grass    !par on top of the grass layer (micro mol photon m-2 s-1)

real albedo_soil  !soil surface albedo
real albedo_veg   !vegetation area albedo
real radnet_soil  !soil surface net radiation, short wave (W m-2)
real radnet_veg   !canopy net radiation, short wave (W m-2)

!climate related recorder
real               gdd0           !growing-degree-day-sum of 0 Celcius base
real               gdd5           !growing-degree-day-sum of 5 Celcius base
real               moist_factor   !adjusted moisture factor for fire spread
real               fire_factor    !factor for fire probability calculation
integer            fire_clo       !counter number of last fire
real,dimension(1:12)::aet         !actual evapotranspiration of last year (mm/month)

!hydrogy related
real                 pool_w1      !soil water content of soil layer 1 (mm)
real                 pool_w2      !soil water content of soil layer 2 (mm)
real                 pool_w3      !soil water content of soil layer 3 (mm)
real                 pool_snow    !water equivalent snow depth (mm)
real                 canopy_cond  !monthly stomatal conductance   (mol H2O m-2 s-1)
real,dimension(365)::pool_w1_RunningRecord !1yr running record of pool_w1

!soil carbon (s.o.m.; soil organic matter)
real pool_litter   !litter pool in a stand (g drymatter / stand)
real pool_som_int  !pool of s.o.m. with intermediated decomposition rate (g drymatter / stand)
real pool_som_slow !pool of s.o.m. with slow decomposition rate (g drymatter / stand)

!water satisfactory for each PFT
real,dimension(PFT_no)    ::stat_water               !state of water satisfactory (0.0-1.0)
real,dimension(PFT_no,365)::stat_water_RunningRecord !1yr running record of stat_water

!photosynthesis related
real,dimension(PFT_no)::eK     !light attenuation coefficient, no dimension
real,dimension(PFT_no)::lue    !monthly quantum yield        (mol CO2 mol photon-1)
real,dimension(PFT_no)::co2cmp !CO2 compensation point       (ppmv)
real,dimension(PFT_no)::psat   !light-saturated photosynthesis rate (micro mol CO2 m-2 s-1)

!individual charactristics of woody PFT
integer,dimension(1:Max_no)::pft            !Plant Functional Type (1-PFT_no)
integer,dimension(1:Max_no)::age            !tree age (year)
integer,dimension(1:Max_no)::height         !tree height from 1.3m above ground (STEP)
integer,dimension(1:Max_no)::bole           !bole length from 1.3m above ground (STEP)
real   ,dimension(1:Max_no)::dbh_heartwood  !heartwood diameter at 1.3m   (m)
real   ,dimension(1:Max_no)::dbh_sapwood    !sapwood   diameter at 1.3m   (m)
real   ,dimension(1:Max_no)::crown_diameter !crown diameter (m)
real   ,dimension(1:Max_no)::crown_area     !crown area     (m2)
real   ,dimension(1:Max_no)::la             !leaf area      (m2)
real   ,dimension(1:Max_no)::mass_leaf      !biomass of foliage  (g)
real   ,dimension(1:Max_no)::mass_trunk     !biomass of stem     (g)
real   ,dimension(1:Max_no)::mass_root      !biomass of root     (g)
real   ,dimension(1:Max_no)::mass_stock     !biomass for stock   (g)
real   ,dimension(1:Max_no)::mass_available !biomass available   (g)
real   ,dimension(1:Max_no)::bole_x         !x_location of bole  (m)
real   ,dimension(1:Max_no)::bole_y         !y_location of bole  (m)
real   ,dimension(1:Max_no)::crown_x        !x_location of crown (m)
real   ,dimension(1:Max_no)::crown_y        !y_location of crown (m)
logical,dimension(1:Max_no)::tree_exist     !tree exist flag
integer,dimension(1:Max_no)::height_limit   !maximum tree height that proximate trees permit
real   ,dimension(1:Max_no)::radius_limit   !maximum canopy radius that proximate trees permit

!grid charactristics of herbaceous PFT
integer            type_grass      !grass type priority in this girid (3:C3 type, 4:C4 type)
integer            C3g_no          !PFT number of C3 grass
integer            C4g_no          !PFT number of C4 grass
real,dimension(2)::gmass_leaf      !c3/c4 herbaceous foliage   biomass in a unit area (g/m2)
real,dimension(2)::gmass_root      !c3/c4 herbaceous root      biomass in a unit area (g/m2)
real,dimension(2)::gmass_available !c3/c4 herbaceous available biomass in a unit area (g/m2)
real,dimension(2)::gmass_stock     !c3/c4 herbaceous stock     biomass in a unit area (g/m2)
real,dimension(2)::lai_grass       !c3/c4 leaf area index of grass (m2/m2)
real,dimension(2)::lai_opt_grass   !c3/c4 optimum LAI for grass (m2/m2)

!dynamics regulate
logical,dimension(PFT_no)::pft_exist             !flag: PFT exist or not (.TRUE. or .FALSE.)
logical,dimension(1:Dived,1:Dived)::patch_vacant !safe site for establishment of woody PFTs

!phenology related
logical,dimension(PFT_no)::phenology !Phenological status (T:foliation, F:dormance)
integer,dimension(PFT_no)::pheno_clo !counter number of last leaf onset
integer,dimension(PFT_no)::pheno_cls !counter number of last leaf shedding
real                     ::pheno_gdd !GDD on 5 degree base
                                     !(reset on 1 Jan for N-hemisphere, 1 July for S-hemisphere)
                                     !
integer                ::pheno_ncd !Number of chilling day, defined as number of days on which
                                   !the daily mean air temperature is below 5 Cecius degree
                                   !(reset on 1 Nov for N-hemisphere, 1 May for S-hemisphere)
                                   !
real,dimension(1:Max_no)    ::stat_leaf !partial differential of NPP to leaf_mass (g NPP / g Leaf)
real,dimension(1:Max_no,1:7)::stat_leaf_RunningRecord  !running record of stat_leaf

!carbon flux recorder
real                    c_emission !monthly carbon emission (C g / month stand)
real                    c_uptake   !monthly carbon uptake   (C g / month stand)
real,dimension(PFT_no)::gpp        !GPP for each pft (g dm / stand / day)
real,dimension(PFT_no)::npp        !NPP for each pft (g dm / stand / day)
real,dimension(PFT_no)::gpp_month  !GPP for each pft (g dm / stand / month)
real,dimension(PFT_no)::npp_month  !NPP for each pft (g dm / stand / month)
real,dimension(PFT_no)::gpp_annual !GPP for each pft (g dm / stand / year)
real,dimension(PFT_no)::npp_annual !NPP for each pft (g dm / stand / year)

!data recorder & average

real               ::establish_regu           !sum of annual precipitation (mm)

real,dimension(365)::tmp_air_RunningRecord    !365days running record  of tmp_air (Celcius)
real,dimension(365)::prec_RunningRecord       !365days running record  of prec    (mm)

real,dimension(30)::tmp_soil_RunningRecord    !30days running record  of tmp_soil (Celcius)
real                tmp_soil_month_ave        !30days running average of tmp_soil (Celcius)

real,dimension(20)::tmp_coldest_RunningRecord !20yr running record  of tmp_coldest_month (Celcius)
real                tmp_coldest_20yr_ave      !20yr running average of tmp_coldest_month (Celcius)

real,dimension(20)::tmp_hottest_RunningRecord !20yr running record  of tmp_hottest_month (Celcius)
real                tmp_hottest_20yr_ave      !20yr running average of tmp_hottest_month (Celcius)

real,dimension(20)::tmp_ave_C3growth_RunningRecord
                 !20yr running record of average temperature of growth phase of C3 grass (Celcius)
real,dimension(20)::tmp_ave_C4growth_RunningRecord
                 !20yr running record of average temperature of growth phase of C4 grass (Celcius)
real,dimension( 2)::tmp_recorder_C3growth
                 !tmperature recorder for C3 growht phase of C3 grass
real,dimension( 2)::tmp_recorder_C4growth
                 !tmperature recorder for C4 growht phase of C4 grass

real,dimension(30)::par_RunningRecord         !30days running record of par

real,dimension(20)::gdd_20yr_RunningRecord    !20yr running record  of growing-degree-day-sum
real                gdd_20yr_ave              !20yr running average of growing-degree-day-sum

real,dimension(PFT_no,365)::npp_RunningRecord !365 days running record of NPP[pft,day] (gDM/stand/day)
real,dimension(        10)::npp_10d_ave       ! 10 days running average of NPP[pft]

real,dimension(1:2,1:20)::lai_opt_grass_RunningRecord !running record of lai_opt_grass (m2/m2)

!hydrogy record
real hydRecord_preci  !sum of precipitation      (mm/month)
real hydRecord_runoff !sum of runoff water       (mm/month)
real hydRecord_ic     !sum of interception water (mm/month)
real hydRecord_ev     !sum of evaporated water   (mm/month)
real hydRecord_tr     !sum of tranpirated water  (mm/month)

!biome type
integer biome  !biome type number (see subroutine biome_type for definition)

!mortality coefficient
real,dimension(1:Max_no)::mort_regu1 ! NPP annual (g dm / individual)
real,dimension(1:Max_no)::mort_regu2 !average leaf area of last year (m2)
real                      mort_regu3 !heat stress for each year for mortality calc.

!local augment
integer doy, i, p
real    x

!air related
co2atm       = 0.0
ap           = 0.0
vp           = 0.0
vpd          = 0.0
dnsa         = 0.0
vp_sat       = 0.0
slope_vps    = 0.0

!radiation related
sl_hgt    = 0.0
dlen      = 0.0
rad       = 0.0
par       = 0.0
par_grass = 0.0

albedo_soil  = 0.0
albedo_veg   = 0.0
radnet_soil  = 0.0
radnet_veg   = 0.0

!climate related recorder
gdd0         = 0.0
gdd5         = 0.0
moist_factor = 0.1
fire_factor  = 0.0
fire_clo     = 0
aet(:)       = 20.0

!hydrogy related
canopy_cond  = 0.0

!water satisfactory for each PFT
stat_water(:)                 = 0.0
stat_water_RunningRecord(:,:) = 0.0

!photosynthesis related
eK(:)     = 0.0
lue(:)    = 0.0
co2cmp(:) = 0.0
psat(:)   = 0.0

!individual charactristics of woody PFT
pft(:)            = 0
age(:)            = 0
height(:)         = 0
bole(:)           = 0
dbh_heartwood(:)  = 0.0
dbh_sapwood(:)    = 0.0
crown_diameter(:) = 0.0
crown_area(:)     = 0.0
la(:)             = 0.0
mass_leaf(:)      = 0.0
mass_trunk(:)     = 0.0
mass_root(:)      = 0.0
mass_stock(:)     = 0.0
mass_available(:) = 0.0
bole_x(:)         = 0.0
bole_y(:)         = 0.0
crown_x(:)        = 0.0
crown_y(:)        = 0.0
tree_exist(:)     = .false. 
height_limit(:)   = 0
radius_limit(:)   = 0.0

!grid charactristics of herbaceous PFT
type_grass           = 3
gmass_leaf(1:2)      = 0.0
gmass_root(1:2)      = 0.0
gmass_available(1:2) = 0.0
gmass_stock(1:2)     = 50.0
lai_opt_grass(1:2)   = 0.0

do p=1, PFT_no
  if (Life_type(p)==3) C3g_no = p
  if (Life_type(p)==4) C4g_no = p
end do

lai_grass(1) = gmass_leaf(1) * SLA(C3g_no)
lai_grass(2) = gmass_leaf(2) * SLA(C4g_no)

!dynamics regulate
pft_exist(:)     = .false.
pft_exist(C3g_no) = .true.
pft_exist(C4g_no) = .true.

patch_vacant(:,:) = .false.

!phenology related
phenology(:) = .false.
do p=1, PFT_no
   if (Phenology_type(p)==0) phenology(p) = .true.   !Evergreen PFTs
   if (Life_type(p)  .ne. 0) phenology(p) = .true.   !Grass PFTs
end do
pheno_clo(:)  = 1
pheno_cls(:)  = 1
pheno_gdd     = 0.0
pheno_ncd     = 1

!leaf income-expenditure balance
stat_leaf(:)                  = 0.0
stat_leaf_RunningRecord(:,:)  = 0.0

!carbon flux recorder
c_emission    = 0.0
c_uptake      = 0.0
gpp(:)        = 1.0
npp(:)        = 1.0
gpp_month(:)  = 1.0
npp_month(:)  = 1.0
gpp_annual(:) = 1.0
npp_annual(:) = 1.0

!data recorder & average
establish_regu = 0.0

tmp_air_RunningRecord(:)  = 0.0
prec_RunningRecord(:)     = 0.0

tmp_soil_RunningRecord(:) = 0.0
tmp_soil_month_ave        = 0.0

tmp_coldest_RunningRecord(:)  = 0.0
tmp_coldest_20yr_ave          = 0.0

tmp_hottest_RunningRecord(:)  = 0.0
tmp_hottest_20yr_ave          = 0.0

par_RunningRecord(:)          = 0.0

gdd_20yr_RunningRecord(:)     = 0.0
gdd_20yr_ave                  = 0.0

npp_RunningRecord(:,:)        = 1.0
npp_10d_ave                   = 1.0

lai_opt_grass_RunningRecord(:,:)  = 0.0

tmp_ave_C3growth_RunningRecord(:) = Topt0(C3g_no)
tmp_recorder_C3growth             = (0.0, 0.0)

tmp_ave_C4growth_RunningRecord(:) = Topt0(C4g_no)
tmp_recorder_C4growth             = (0.0, 0.0)

!hydrogy record
hydRecord_preci  = 0.0
hydRecord_runoff = 0.0
hydRecord_ic     = 0.0
hydRecord_ev     = 0.0
hydRecord_tr     = 0.0

!biome type
biome = 17 !desert

!Temperature recorder
do i = 1, 365
   tmp_air_RunningRecord(i) = tmp_air(i)
   prec_RunningRecord(i)    = prec(i)
end do

do i = 1, 30
   tmp_soil_RunningRecord (i) = tmp_soil(335+i)
end do

tmp_soil_month_ave  = sum(tmp_soil(336:365)) / 30.0

!Growing degree day
x = 0.0
do doy = 1, 365
   x = x + max(0.0, tmp_air(doy)-5.0)
end do
gdd_20yr_RunningRecord(1:20) = x
gdd_20yr_ave                 = x

!Soil water conditions
    x = 0.5 !initialize value of moisture per water holding capacity
    
    pool_w1                  = x * W_sat * Depth1
    pool_w2                  = x * W_sat * Depth2
    pool_w2                  = x * W_sat * Depth3
    pool_snow                = 0.000
    pool_w1_RunningRecord(:) = pool_w1
    
    pool_litter   = 1.0 * Max_loc * Max_loc
    pool_som_int  = 1.0 * Max_loc * Max_loc
    pool_som_slow = 1.0 * Max_loc * Max_loc

!initialize heat stress
mort_regu1(:) = 0.0
mort_regu2(:) = 0.0
mort_regu3    = 0.0
do doy = 1, 365
   mort_regu3 = min(1.0, mort_regu3 + max(0.0, tmp_air(doy)-Heat_base) / 300.0 )
end do

END SUBROUTINE init_value



!**************************************************************************************************
! Initialization for new Sapling
!**************************************************************************************************
SUBROUTINE init_tree &
          (par, par_grass, pool_litter, c_uptake, &
          pft, age, height, bole, dbh_heartwood, dbh_sapwood, &
          crown_diameter, crown_area, la, &
          mass_leaf, mass_trunk, mass_root, mass_stock, mass_available, &
          tree_exist, height_limit, radius_limit, &
          mort_regu1, mort_regu2, &
          stat_leaf, stat_leaf_RunningRecord, stat_leaf_crowntop, stat_leaf_crownbottom )

USE data_structure
implicit none

!Define Arguments
real   ,intent(IN)   ::par          !photosynthetically active radiation of mid-day
real   ,intent(IN)   ::par_grass    !par under tree canopy
real   ,intent(INOUT)::pool_litter  !litter pool in a stand (g / stand)
real   ,intent(INOUT)::c_uptake     !monthly carbon uptake  (C g / month stand)

integer,intent(IN) ::pft            !Plant Functional Type (1-PFT_no)
integer,intent(OUT)::age            !tree age (year)
integer,intent(OUT)::height         !tree height from 1.3m above ground (STEP)
integer,intent(OUT)::bole           !bole length from 1.3m above ground (STEP)
real   ,intent(OUT)::dbh_heartwood     !heartwood diameter at 1.3m   (m)
real   ,intent(OUT)::dbh_sapwood     !sapwood diameter at 1.3m   (m)
real   ,intent(OUT)::crown_diameter !crown diameter (m)
real   ,intent(OUT)::crown_area     !crown area (m2)
real   ,intent(OUT)::la             !leaf area (m2)
real   ,intent(OUT)::mass_leaf         !biomass of foliage (g)
real   ,intent(OUT)::mass_trunk         !biomass of stem (g)
real   ,intent(OUT)::mass_root         !biomass of root (g)
real   ,intent(OUT)::mass_stock     !biomass for stock (g)
real   ,intent(OUT)::mass_available !biomass available (g)

logical,intent(OUT)::tree_exist   !tree exist or not (.TRUE. or .FALSE.)
integer,intent(OUT)::height_limit !max_tree_height proximate trees permit
real   ,intent(OUT)::radius_limit !max_canopy_radius proximate trees permit
real   ,intent(OUT)::mort_regu1   !NPP annual (g dm / individual)
real   ,intent(OUT)::mort_regu2   !average leaf area of last year (m2/day)

real              ,intent(OUT)::stat_leaf               !(income-expenditure)/leaf_mass
real,dimension(7) ,intent(OUT)::stat_leaf_RunningRecord !running record of stat_leaf
real              ,intent(OUT)::stat_leaf_crowntop      !stat_leaf of crown top
real,dimension(10),intent(OUT)::stat_leaf_crownbottom   !stat_leaf of crown bottom

!Define local variables
real mass_total

!Initialization
   tree_exist       = .true.
   age              = 1
   dbh_sapwood      = 0.01   ! <--- this value determine initial size of new sapling
   dbh_heartwood    = 0.00
   height           = h(dbh_sapwood + dbh_heartwood, pft)
   bole             = 0
   crown_area       = ca(dbh_sapwood + dbh_heartwood, pft)
   crown_diameter   = 2 * sqrt(crown_area/PI)
   la               = 0.0   !alternative:  2.0 * crown_area * height * STEP
   mort_regu1       = 0.0
   mort_regu2       = la / 365
   mass_leaf        = 0.0   !alternative:  la / SLA(pft)
   mass_root        = 0.0   !alternative:  mass_leaf / FR_ratio(pft)
   mass_trunk       = ALM3(pft) * ((dbh_sapwood + dbh_heartwood)**2)*PI/4.0 * (1.3+height*STEP)
   mass_stock       = 250.0
   mass_available   = 250.0
   
   height_limit     = height
   radius_limit     = sqrt(crown_area/PI)
   
   stat_leaf                  = 0.00
   stat_leaf_RunningRecord(:) = stat_leaf
   stat_leaf_crowntop         = stat_leaf
   stat_leaf_crownbottom(:)   = stat_leaf

!Adjust carbon balance
   mass_total  = mass_leaf + mass_trunk + mass_root + mass_stock + mass_available
   pool_litter = max(0.0, pool_litter - mass_total)
   !c_uptake    = c_uptake + mass_total * C_in_drymass
   
END SUBROUTINE init_tree



!**************************************************************************************************
! death of Woody pft
!**************************************************************************************************
SUBROUTINE die_tree &
    ( height, bole, dbh_heartwood, dbh_sapwood, crown_diameter, crown_area, la, mort_regu2, &
    mass_leaf, mass_trunk, mass_root, mass_stock, mass_available, age, pft, &
    height_limit, radius_limit, mort_regu1, &
    stat_leaf, stat_leaf_RunningRecord, stat_leaf_crowntop, stat_leaf_crownbottom, &
    tree_exist, pool_litter )

USE data_structure
implicit none

!Define Arguments
real,intent(INOUT)::pool_litter    !litter pool in a stand (g / stand)
real,intent(INOUT)::mass_leaf      !biomass of foliage (g)
real,intent(INOUT)::mass_trunk     !biomass of stem (g)
real,intent(INOUT)::mass_root      !biomass of root (g)
real,intent(INOUT)::mass_stock     !biomass for stock (g)
real,intent(INOUT)::mass_available !biomass available (g)

integer,intent(OUT)::pft            !Plant Functional Type (1-PFT_no)
integer,intent(OUT)::age            !tree age (year)
integer,intent(OUT)::height         !tree height from 1.3m above ground (STEP)
integer,intent(OUT)::bole           !bole length from 1.3m above ground (STEP)
real   ,intent(OUT)::dbh_heartwood  !heartwood diameter at 1.3m (m)
real   ,intent(OUT)::dbh_sapwood    !sapwood diameter at 1.3m (m)
real   ,intent(OUT)::crown_diameter !crown diameter (m)
real   ,intent(OUT)::crown_area     !crown area (m2)
real   ,intent(OUT)::la             !leaf area (m2)
logical,intent(OUT)::tree_exist     !tree exist or not (.TRUE. or .FALSE.)

integer,intent(OUT)::height_limit !max_tree_height proximate trees permit
real   ,intent(OUT)::radius_limit !max_canopy_radius proximate trees permit
real   ,intent(OUT)::mort_regu1   !NPP sum within the previous year (g dm)
real   ,intent(OUT)::mort_regu2   !average leaf area of last year (m2/day)

real              ,intent(OUT)::stat_leaf               !(income-expenditure)/leaf_mass
real,dimension(7) ,intent(OUT)::stat_leaf_RunningRecord !running record of stat_leaf
real              ,intent(OUT)::stat_leaf_crowntop      !stat_leaf of crown top
real,dimension(10),intent(OUT)::stat_leaf_crownbottom   !stat_leaf of crown bottom

!Increase pool_litter
    pool_litter = pool_litter + &
                  mass_leaf + mass_trunk + mass_root + mass_available + mass_stock

!Clear tree
    tree_exist      = .false.
    pft             = 0  
    age             = 0  
    height          = 0  
    bole            = 0  
    dbh_sapwood     = 0.0
    dbh_heartwood   = 0.0
    crown_area      = 0.0
    crown_diameter  = 0.0
    la              = 0.0
    mort_regu1      = 0.0
    mort_regu2      = 0.0
    mass_leaf       = 0.0
    mass_root       = 0.0
    mass_trunk      = 0.0
    mass_stock      = 0.0
    mass_available  = 0.0
    
    height_limit    = 0
    radius_limit    = 0.0
    
    stat_leaf                  = 0.0
    stat_leaf_RunningRecord(:) = 0.0
    stat_leaf_crowntop         = 0.0
    stat_leaf_crownbottom(:)   = 0.0
    
END SUBROUTINE die_tree
